#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_CUMSUM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_CUMSUM_HPP_INCLUDED

#include <boost/simd/swar/include/functions/cumsum.hpp>

#endif
